import request from '@/utils/request'

// 查询设备列表
export function listDevice(devId) {
    return request({
        url: '/mf/device',
        method: 'get',
        params: { devId }
    })
}

// 查询设备能耗排行
export function listElect(type) {
    return request({
        url: '/mf/elect?type=' + type,
        method: 'get',
    })
}

// 查询设备用电监测
export function electMonitoring() {
    return request({
        url: '/mf/electMonitoring',
        method: 'get',
    })
}

// 查询设备状态
export function deviceStatus() {
    return request({
        url: '/mf/deviceStatus',
        method: 'get',
    })
}

// 设备利用率
export function deviceRate() {
    return request({
        url: '/mf/deviceRate',
        method: 'get',
    })
}

// 设备保养提醒
export function deviceCheck(devId) {
    return request({
        url: '/mf/deviceCheck',
        method: 'get',
        params: { devId }
    })
}

//设备报警记录
export function deviceRepair(devId) {
    return request({
        url: '/mf/deviceRepair',
        method: 'get',
        params: { devId }
    })
}

//单设备运行状态
export function deviceStatusById(devId) {
    return request({
        url: '/mf/deviceStatusById',
        method: 'get',
        params: { devId }
    })
}
//单设备运行状态
export function deviceStatusChart(devId) {
    return request({
        url: '/mf/deviceStatusChart',
        method: 'get',
        params: { devId }
    })
}

//单设备运行状态
export function deviceRateChart(devId) {
    return request({
        url: '/mf/deviceRateChart',
        method: 'get',
        params: { devId }
    })
}

//单设备用电量图表
export function deviceElectChart(devId) {
    return request({
        url: '/mf/deviceElectChart',
        method: 'get',
        params: { devId }
    })
}



